==> aloe-1.4.2.tar.gz: aloe-1.4.2/modules/utran_turbodecoder/interfaces/stats.h <==

#ifndef _STATS_H
#define	_STATS_H


int longblock,numblocks;
int stat_signal;
int datatype;
int stat_dynhalt,stat_iters,stat_rh,stat_maxiters,stat_outsignal,stat_insignal;

int dynamic_halt=800,iterations,real_halt,max_iterations=1;

int samples[INPUT_MAX_DATA];
char output_bits[8*INPUT_MAX_DATA];

struct utils_param params[] = {
		{"datatype",STAT_TYPE_INT,1,&datatype},
		{"numblocks",STAT_TYPE_INT,1,&numblocks},
		{"longblock",STAT_TYPE_INT,1,&longblock},
		{"max_iterations",STAT_TYPE_INT,1,&max_iterations},
		{"dynHalt",STAT_TYPE_INT,1,&dynamic_halt},
                            {NULL, 0, 0, 0}};


struct utils_stat stats[] = {     
							{"inputSignal",
							STAT_TYPE_INT,
							1024,
							&stat_insignal,
							(void*)samples,
							WRITE},

							{"outputSignal",
							STAT_TYPE_CHAR,
							1024,
							&stat_outsignal,
							(void*)output_bits,
							WRITE},

							{"dynHalt",
                            STAT_TYPE_INT,
                            1,
                            &stat_dynhalt,
                            (void*)&dynamic_halt,
                            READ},

                             {"iterations",
                            STAT_TYPE_INT,
                            1,
                            &stat_iters,
                            (void*)&iterations,
                            OFF},

                             {"max_iterations",
                            STAT_TYPE_INT,
                            1,
                            &stat_maxiters,
                            (void*)&max_iterations,
                            READ},

                             {"realHalt",
                            STAT_TYPE_INT,
                            1,
                            &stat_rh,
                            (void*)&real_halt,
                            WRITE},

                            {NULL, 0, 0, 0, 0, 0}};


#endif	/* _STATS_H */

==> aloe-1.4.5.tar.gz: aloe-1.4.5/modules/utran_turbodecoder/interfaces/stats.h <==

#ifndef _STATS_H
#define	_STATS_H


int longblock,numblocks;
int stat_signal;
int datatype;
int stat_dh_method,dh_method;
int stat_dynhalt,stat_iters,stat_rh,stat_maxiters,stat_outsignal,stat_insignal;

int dynamic_halt=800,iterations,real_halt,max_iterations=1;

int samples[INPUT_MAX_DATA];
char output_bits[8*INPUT_MAX_DATA];

struct utils_param params[] = {
		{"datatype",STAT_TYPE_INT,1,&datatype},
		{"numblocks",STAT_TYPE_INT,1,&numblocks},
		{"longblock",STAT_TYPE_INT,1,&longblock},
		{"max_iterations",STAT_TYPE_INT,1,&max_iterations},
		{"halt_threshold",STAT_TYPE_INT,1,&dynamic_halt},
		{"halt_method",STAT_TYPE_INT,1,&dh_method},
                            {NULL, 0, 0, 0}};


struct utils_stat stats[] = {     
							{"inputSignal",
							STAT_TYPE_INT,
							1024,
							&stat_insignal,
							(void*)samples,
							WRITE},

							{"outputSignal",
							STAT_TYPE_CHAR,
							1024,
							&stat_outsignal,
							(void*)output_bits,
							WRITE},

							{"halt_threshold",
                            STAT_TYPE_INT,
                            1,
                            &stat_dynhalt,
                            (void*)&dynamic_halt,
                            READ},

                             {"iterations",
                            STAT_TYPE_INT,
                            1,
                            &stat_iters,
                            (void*)&iterations,
                            WRITE},

                             {"halt_method",
                            STAT_TYPE_INT,
                            1,
                            &stat_dh_method,
                            (void*)&dh_method,
                            READ},

                            {"max_iterations",
						   STAT_TYPE_INT,
						   1,
						   &stat_maxiters,
						   (void*)&max_iterations,
						   READ},

                             {"llr",
                            STAT_TYPE_INT,
                            1,
                            &stat_rh,
                            (void*)&real_halt,
                            WRITE},

                            {NULL, 0, 0, 0, 0, 0}};


#endif	/* _STATS_H */
